@@ -83,6 +83,11 @@ def completed(function_name):
 
 
 def aux_logger(in_name):
+
+    return logging.getLogger(in_name)
+
+
+def alt_aux_logger(in_name):
     in_name = in_name.split('.')
     in_name = in_name[-1]
     return logging.getLogger('main.' + in_name)
@@ -137,7 +142,7 @@ class CustomFormatter(logging.Formatter):
 
 def _each_run_file_rotate_handler(in_file_name, in_back_up):
     _date_format = DATEFORMAT_DEV if os.getenv('IS_DEV') == "1" else DATEFORMAT_STD
-    formatter = CustomFormatter(fmt='{asctime} |{levelname:^9}|{threadName:^14}|{lineno:^7}| {name:<35}|{funcName:^35}||--> {message}', datefmt=_date_format, style='{')
+    formatter = CustomFormatter(fmt='{asctime} |{levelname:^11}|{threadName:^14}|{lineno:^7}| {name:<35}|{funcName:^35}||--> {message}', datefmt=_date_format, style='{')
     handler = handlers.RotatingFileHandler(in_file_name, mode='a', backupCount=in_back_up, maxBytes=10 * (1024 * 1024))
     handler.namer = std_namer
     handler.setFormatter(formatter)
@@ -146,7 +151,7 @@ def _each_run_file_rotate_handler(in_file_name, in_back_up):
 
 def _stdout_handler():
     _date_format = DATEFORMAT_DEV if os.getenv('IS_DEV') == "1" else DATEFORMAT_STD
-    formatter = CustomFormatter(fmt='{asctime} |{levelname:^9}|{threadName:^14}|{lineno:^7}| {name:<35}|{funcName:^35}||--> {message}', datefmt=_date_format, style='{')
+    formatter = CustomFormatter(fmt='{asctime} |{levelname:^11}|{threadName:^14}|{lineno:^7}| {name:<35}|{funcName:^35}||--> {message}', datefmt=_date_format, style='{')
     # formatter = logging.Formatter(fmt='[{asctime}][{levelname:^7}][{name:<30}][{funcName:^25}] --> {message}', datefmt=_date_format, style='{')
     handler = logging.StreamHandler()
     handler.setFormatter(formatter)
@@ -161,7 +166,7 @@ def main_logger(in_file_name, in_level='DEBUG', in_back_up=2, other_logger_names
     _out = logging.getLogger('main')
     all_loggers = [_out] + list(map(logging.getLogger, other_logger_names)) if other_logger_names is not None else [_out]
     for logger in all_loggers:
-        logger.setLevel(getattr(logging, in_level.upper()))
+        logger.setLevel(in_level.upper())
         if log_to in ['both', 'file']:
             logger.addHandler(run_rotating_file_handler)
         if log_to in ['both', 'stdout']:
@@ -176,7 +181,7 @@ def main_logger(in_file_name, in_level='DEBUG', in_back_up=2, other_logger_names
 def main_logger_stdout(in_level):
 
     _out = logging.getLogger('main')
-    _out.setLevel(getattr(logging, in_level.upper()))
+    _out.setLevel(in_level.upper())
 
     _out.addHandler(_stdout_handler())
 
